==> mt-bean-validators-2.0.15.jar: de/knightsoftnet/validators/shared/impl/AgeLimitCheckValidatorForCalendar.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package de.knightsoftnet.validators.shared.impl;

import org.apache.commons.lang3.time.DateUtils;

import java.util.Calendar;

import jakarta.validation.ConstraintValidatorContext;

/**
 * Check if a given date is minYears years ago for Calendar.
 *
 * @author Manfred Tremmel
 *
 */
public class AgeLimitCheckValidatorForCalendar extends AbstractAgeLimitCheckValidator<Calendar> {

  @Override
  public final boolean isValid(final Calendar pvalue, final ConstraintValidatorContext pcontext) {
    if (pvalue == null) {
      return true;
    }
    final Calendar limitExact = Calendar.getInstance();
    limitExact.add(Calendar.YEAR, 0 - minYears);
    final Calendar dateLimit = DateUtils.truncate(limitExact, Calendar.DAY_OF_MONTH);
    final Calendar birthday = DateUtils.truncate(pvalue, Calendar.DAY_OF_MONTH);
    return !dateLimit.before(birthday);
  }
}

==> mt-bean-validators-2.4.5.jar: de/knightsoftnet/validators/shared/impl/AgeLimitCheckValidatorForCalendar.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more contributor license
 * agreements. See the NOTICE file distributed with this work for additional information regarding
 * copyright ownership. The ASF licenses this file to You under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

package de.knightsoftnet.validators.shared.impl;

import org.apache.commons.lang3.time.DateUtils;

import java.util.Calendar;

import jakarta.validation.ConstraintValidatorContext;

/**
 * Check if a given date is minYears years ago for Calendar.
 *
 * @author Manfred Tremmel
 *
 */
public class AgeLimitCheckValidatorForCalendar extends AbstractAgeLimitCheckValidator<Calendar> {

  @Override
  public final boolean isValid(final Calendar value, final ConstraintValidatorContext context) {
    if (value == null) {
      return true;
    }
    final Calendar limitExact = Calendar.getInstance();
    limitExact.add(Calendar.YEAR, 0 - minYears);
    final Calendar dateLimit = DateUtils.truncate(limitExact, Calendar.DAY_OF_MONTH);
    final Calendar birthday = DateUtils.truncate(value, Calendar.DAY_OF_MONTH);
    return !dateLimit.before(birthday);
  }
}
